@@ -20,9 +20,11 @@
 
 import pandas as _pd
 import numpy as _np
+from math import sqrt as _sqrt
 from datetime import (
     datetime as _dt, timedelta as _td
 )
+from base64 import b64encode as _b64encode
 import re as _regex
 from tabulate import tabulate as _tabulate
 from . import (
@@ -38,16 +40,16 @@ except ImportError:
     pass
 
 
-def html(returns, benchmark=None, rf=0.,
-         grayscale=False, title='Strategy Tearsheet',
-         output=None, compounded=True, rolling_period=126,
-         download_filename='quantstats-tearsheet.html'):
+def html(returns, benchmark=None, rf=0., grayscale=False,
+         title='Strategy Tearsheet', output=None, compounded=True,
+         rolling_period=126, download_filename='quantstats-tearsheet.html',
+         figfmt='svg', template_path=None):
 
     if output is None and not _utils._in_notebook():
         raise ValueError("`file` must be specified")
 
     tpl = ""
-    with open(__file__[:-4] + '.html') as f:
+    with open(template_path or __file__[:-4] + '.html') as f:
         tpl = f.read()
         f.close()
 
@@ -99,102 +101,102 @@ def html(returns, benchmark=None, rf=0.,
     figfile = _utils._file_stream()
     _plots.returns(returns, benchmark, grayscale=grayscale,
                    figsize=(8, 5), subtitle=False,
-                   savefig={'fname': figfile, 'format': 'svg'},
+                   savefig={'fname': figfile, 'format': figfmt},
                    show=False, ylabel=False, cumulative=compounded)
-    tpl = tpl.replace('{{returns}}', figfile.getvalue().decode())
+    tpl = tpl.replace('{{returns}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.log_returns(returns, benchmark, grayscale=grayscale,
                        figsize=(8, 4), subtitle=False,
-                       savefig={'fname': figfile, 'format': 'svg'},
+                       savefig={'fname': figfile, 'format': figfmt},
                        show=False, ylabel=False, cumulative=compounded)
-    tpl = tpl.replace('{{log_returns}}', figfile.getvalue().decode())
+    tpl = tpl.replace('{{log_returns}}', _embed_figure(figfile, figfmt))
 
     if benchmark is not None:
         figfile = _utils._file_stream()
         _plots.returns(returns, benchmark, match_volatility=True,
                        grayscale=grayscale, figsize=(8, 4), subtitle=False,
-                       savefig={'fname': figfile, 'format': 'svg'},
+                       savefig={'fname': figfile, 'format': figfmt},
                        show=False, ylabel=False, cumulative=compounded)
-        tpl = tpl.replace('{{vol_returns}}', figfile.getvalue().decode())
+        tpl = tpl.replace('{{vol_returns}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.yearly_returns(returns, benchmark, grayscale=grayscale,
                           figsize=(8, 4), subtitle=False,
-                          savefig={'fname': figfile, 'format': 'svg'},
+                          savefig={'fname': figfile, 'format': figfmt},
                           show=False, ylabel=False, compounded=compounded)
-    tpl = tpl.replace('{{eoy_returns}}', figfile.getvalue().decode())
+    tpl = tpl.replace('{{eoy_returns}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.histogram(returns, grayscale=grayscale,
                      figsize=(8, 4), subtitle=False,
-                     savefig={'fname': figfile, 'format': 'svg'},
+                     savefig={'fname': figfile, 'format': figfmt},
                      show=False, ylabel=False, compounded=compounded)
-    tpl = tpl.replace('{{monthly_dist}}', figfile.getvalue().decode())
+    tpl = tpl.replace('{{monthly_dist}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.daily_returns(returns, grayscale=grayscale,
                          figsize=(8, 3), subtitle=False,
-                         savefig={'fname': figfile, 'format': 'svg'},
+                         savefig={'fname': figfile, 'format': figfmt},
                          show=False, ylabel=False)
-    tpl = tpl.replace('{{daily_returns}}', figfile.getvalue().decode())
+    tpl = tpl.replace('{{daily_returns}}', _embed_figure(figfile, figfmt))
 
     if benchmark is not None:
         figfile = _utils._file_stream()
         _plots.rolling_beta(returns, benchmark, grayscale=grayscale,
                             figsize=(8, 3), subtitle=False,
-                            savefig={'fname': figfile, 'format': 'svg'},
+                            savefig={'fname': figfile, 'format': figfmt},
                             show=False, ylabel=False)
-        tpl = tpl.replace('{{rolling_beta}}', figfile.getvalue().decode())
+        tpl = tpl.replace('{{rolling_beta}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.rolling_volatility(returns, benchmark, grayscale=grayscale,
                               figsize=(8, 3), subtitle=False,
-                              savefig={'fname': figfile, 'format': 'svg'},
+                              savefig={'fname': figfile, 'format': figfmt},
                               show=False, ylabel=False, period=rolling_period)
-    tpl = tpl.replace('{{rolling_vol}}', figfile.getvalue().decode())
+    tpl = tpl.replace('{{rolling_vol}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.rolling_sharpe(returns, grayscale=grayscale,
                           figsize=(8, 3), subtitle=False,
-                          savefig={'fname': figfile, 'format': 'svg'},
+                          savefig={'fname': figfile, 'format': figfmt},
                           show=False, ylabel=False, period=rolling_period)
-    tpl = tpl.replace('{{rolling_sharpe}}', figfile.getvalue().decode())
+    tpl = tpl.replace('{{rolling_sharpe}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.rolling_sortino(returns, grayscale=grayscale,
                            figsize=(8, 3), subtitle=False,
-                           savefig={'fname': figfile, 'format': 'svg'},
+                           savefig={'fname': figfile, 'format': figfmt},
                            show=False, ylabel=False, period=rolling_period)
-    tpl = tpl.replace('{{rolling_sortino}}', figfile.getvalue().decode())
+    tpl = tpl.replace('{{rolling_sortino}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.drawdowns_periods(returns, grayscale=grayscale,
                              figsize=(8, 4), subtitle=False,
-                             savefig={'fname': figfile, 'format': 'svg'},
+                             savefig={'fname': figfile, 'format': figfmt},
                              show=False, ylabel=False, compounded=compounded)
-    tpl = tpl.replace('{{dd_periods}}', figfile.getvalue().decode())
+    tpl = tpl.replace('{{dd_periods}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.drawdown(returns, grayscale=grayscale,
                     figsize=(8, 3), subtitle=False,
-                    savefig={'fname': figfile, 'format': 'svg'},
+                    savefig={'fname': figfile, 'format': figfmt},
                     show=False, ylabel=False)
-    tpl = tpl.replace('{{dd_plot}}', figfile.getvalue().decode())
+    tpl = tpl.replace('{{dd_plot}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.monthly_heatmap(returns, grayscale=grayscale,
                            figsize=(8, 4), cbar=False,
-                           savefig={'fname': figfile, 'format': 'svg'},
+                           savefig={'fname': figfile, 'format': figfmt},
                            show=False, ylabel=False, compounded=compounded)
-    tpl = tpl.replace('{{monthly_heatmap}}', figfile.getvalue().decode())
+    tpl = tpl.replace('{{monthly_heatmap}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.distribution(returns, grayscale=grayscale,
                         figsize=(8, 4), subtitle=False,
-                        savefig={'fname': figfile, 'format': 'svg'},
+                        savefig={'fname': figfile, 'format': figfmt},
                         show=False, ylabel=False, compounded=compounded)
-    tpl = tpl.replace('{{returns_dist}}', figfile.getvalue().decode())
+    tpl = tpl.replace('{{returns_dist}}', _embed_figure(figfile, figfmt))
 
     tpl = _regex.sub(r'\{\{(.*?)\}\}', '', tpl)
     tpl = tpl.replace('white-space:pre;', '')
@@ -304,7 +306,7 @@ def metrics(returns, benchmark=None, rf=0., display=True,
     pct = 100 if display or "internal" in kwargs else 1
 
     # return df
-    dd = _calc_dd(df['returns'], display=(display or "internal" in kwargs))
+    dd = _calc_dd(df, display=(display or "internal" in kwargs))
 
     metrics = _pd.DataFrame()
 
@@ -331,8 +333,14 @@ def metrics(returns, benchmark=None, rf=0., display=True,
         metrics['Total Return %'] = (df.sum() * pct).map('{:,.2f}'.format)
 
     metrics['CAGR%%'] = _stats.cagr(df, rf, compounded) * pct
+
+    metrics['~~~~~~~~~~~~~~'] = blank
+
     metrics['Sharpe'] = _stats.sharpe(df, rf)
     metrics['Sortino'] = _stats.sortino(df, rf)
+    metrics['Sortino/√2'] = metrics['Sortino'] / _sqrt(2)
+
+    metrics['~~~~~~~~'] = blank
     metrics['Max Drawdown %'] = blank
     metrics['Longest DD Days'] = blank
 
@@ -364,6 +372,14 @@ def metrics(returns, benchmark=None, rf=0., display=True,
 
     metrics['~~~~~~'] = blank
 
+    metrics['Gain/Pain Ratio'] = _stats.gain_to_pain_ratio(df, rf)
+    metrics['Gain/Pain (1M)'] = _stats.gain_to_pain_ratio(df, rf, "M")
+    # if mode.lower() == 'full':
+    #     metrics['GPR (3M)'] = _stats.gain_to_pain_ratio(df, rf, "Q")
+    #     metrics['GPR (6M)'] = _stats.gain_to_pain_ratio(df, rf, "2Q")
+    #     metrics['GPR (1Y)'] = _stats.gain_to_pain_ratio(df, rf, "A")
+    metrics['~~~~~~~'] = blank
+
     metrics['Payoff Ratio'] = _stats.payoff_ratio(df)
     metrics['Profit Factor'] = _stats.profit_factor(df)
     metrics['Common Sense Ratio'] = _stats.common_sense_ratio(df)
@@ -563,8 +579,6 @@ def plots(returns, benchmark=None, grayscale=False,
 
 
 def _calc_dd(df, display=True):
-    if isinstance(df, _pd.DataFrame):
-        df = df[df.columns[0]]
     dd = _stats.to_drawdown_series(df)
     dd_info = _stats.drawdown_details(dd)
 
@@ -644,3 +658,11 @@ def _open_html(html):
         ' +', ' ', html.replace('\n', '')))
     if _utils._in_notebook():
         iDisplay(iHTML(jscode))
+
+
+def _embed_figure(figfile, figfmt):
+    figbytes = figfile.getvalue()
+    if figfmt == 'svg':
+        return figbytes.decode()
+    data_uri = _b64encode(figbytes).decode()
+    return '<img src="data:image/{};base64,{}" />'.format(figfmt, data_uri)
