@@ -252,7 +252,7 @@ def adjusted_sortino(returns, rf=0, periods=252, annualize=True):
     direct comparisons to the Sharpe. See here for more info:
     https://archive.is/wip/2rwFW
     """
-    data = sortino(returns, rf=0, periods=252, annualize=True)
+    data = sortino(returns, rf=0, periods=periods, annualize=annualize)
     return data / _sqrt(2)
 
 
@@ -646,6 +646,7 @@ def rolling_greeks(returns, benchmark, periods=252):
         "returns": _utils._prepare_returns(returns),
         "benchmark": _utils._prepare_benchmark(benchmark, returns.index)
     })
+    df = df.fillna(0)
     corr = df.rolling(int(periods)).corr().unstack()['returns']['benchmark']
     std = df.rolling(int(periods)).std()
     beta = corr * std['returns'] / std['benchmark']
